=======================
Scipion - Dynamo plugin
=======================

This is a plugin for **scipion** and dynamo

=====
Setup
=====

- **Install this plugin in devel mode:**

Using the command line:

.. code-block::

    scipion installp -p local/path/to/scipion-em-dynamo --devel

